NamedTensor

Struct NamedTensor 

pub struct NamedTensor<B: Backend, D: NamedDims<B>> { /* private fields */ }
A tensor with named dimensions.

Implementations

Source

impl<B: Backend, const D: usize, ND> NamedTensor<B, ND>
where ND: NamedDims<B, Tensor = Tensor<B, D>>,

pub fn from_tensor(tensor: Tensor<B, D>) -> Self

Create a named tensor from a tensor.

pub fn random<S: Into<Shape>>( shape: S, distribution: Distribution, device: &B::Device, ) -> Self

Create a random named tensor of the given shape where each element is sampled from the given distribution.

pub fn shape(&self) -> Shape

Returns the shape of the current tensor.

pub fn mul(self, rhs: Self) -> Self

Applies element wise multiplication operation.

y = x2 * x1

pub fn reshape<const D2: usize, S, ND2>( self, shape: S, _: ND2, ) -> NamedTensor<B, ND2>
where S: Into<Shape>, ND2: NamedDims<B, Tensor = Tensor<B, D2>>,

Reshape the tensor to have the given shape.

Panics

If the tensor can not be reshape to the given shape.

Source

impl<B: Backend, const D: usize, ND> NamedTensor<B, ND>
where ND: NamedDims<B, Tensor = Tensor<B, D>>,

pub fn matmul<NamedDimsRhs, NamedDimsOut>( self, rhs: NamedTensor<B, NamedDimsRhs>, ) -> NamedTensor<B, NamedDimsOut>
where NamedDimsRhs: NamedDims<B, Tensor = Tensor<B, D>>, NamedDimsOut: NamedDims<B, Tensor = Tensor<B, D>>, Self: Matmul<NamedTensor<B, NamedDimsRhs>, NamedTensor<B, NamedDimsOut>>,

Applies the matrix multiplication operation.

C = AB

Panics

If the two tensors dont’ have a compatible shape.

Source

impl<B: Backend, const D: usize, ND> NamedTensor<B, ND>
where ND: NamedDims<B, Tensor = Tensor<B, D>>,

pub fn swap_dims<ND2, const D1: usize, const D2: usize>( self, ) -> NamedTensor<B, ND2>
where ND2: NamedDims<B, Tensor = Tensor<B, D>>, Self: SwapDims<NamedTensor<B, ND2>, D1, D2>,

Swap two dimensions.